@@ -9,14 +9,19 @@
 #' @param edge Numeric. Trimming amount applied to the outermost quantiles (default \code{0.05}).
 #' @param scenario Optional list of matrices representing a stressed scenario, as returned by \code{create_scenario()}.
 #' @param min Logical. If \code{TRUE} (default), implement a stepwise minimization. If \code{FALSE}, implement a stepwise maximization. 
-#'
+#' @param QTAU Numeric. Quantile level (default \code{0.05}) used to compute stressed factors via \code{compute_stressed_factors()}. Only used if \code{scenario} is provided.
+#' 
 #' @return A list containing:
 #' \describe{
 #'   \item{\code{Quantiles}}{Matrix of forecasted quantiles (rows = time, cols = quantile levels).}
-#'   \item{\code{Scenario_Quantiles}}{Matrix of stressed scenario quantiles (same format), returned only if \code{scenario} is provided.}
+#'   \item{\code{Strssed_Quantiles}}{Matrix of stressed scenario quantiles (same format), returned only if \code{scenario} is provided.}
 #'   \item{\code{Coeff}}{Matrix of quantile regression coefficients for each quantile.}
 #'   \item{\code{Std. Error}}{Matrix of Std. Error for each regression coefficient.}
 #'   \item{\code{Pvalue}}{Matrix of p-values for each regression coefficient.}
+#'   \item{\code{QTAU}}{The quantile level used to compute stressed factors (if applicable).}
+#'   \item{\code{Stressed_Factors}}{Matrix of selected stressed factors (only if \code{scenario} is provided and \code{QTAU} is set).}
+
+
 #' }
 #' 
 #' @examples
@@ -27,7 +32,7 @@
 #' global = 1
 #' local <- c(1, 1)   
 #' mldfm_result <- mldfm(data, blocks = 2, block_ind = block_ind, global = global , local = local)
-#' fars_result <- compute_fars(dep_variable, mldfm_result$Factors, h = 1, edge = 0.05, min = TRUE)
+#' fars_result <- compute_fars(dep_variable, mldfm_result$Factors, h = 1, edge = 0.05)
 #' }
 #'  
 #'  
@@ -37,13 +42,20 @@ compute_fars <- function(dep_variable,
                          h = 1, 
                          edge = 0.05, 
                          scenario = NULL, 
-                         min = TRUE) {
+                         min = TRUE,
+                         QTAU = 0.05) {
  
   if (!is.numeric(dep_variable)) stop("dep_variable must be a numeric vector.")
   if (!is.matrix(factors) && !is.data.frame(factors)) stop("factors must be a matrix or data frame.")
   if (!is.numeric(h) || h < 1) stop("h must be a positive integer.")
   if (!is.numeric(edge) || edge < 0 || edge > 0.5) stop("edge must be a number between 0 and 0.5.")
   if (!is.null(scenario) && !is.list(scenario)) stop("scenario must be a list of matrices, as returned by create_scenario().")
+  if (!is.logical(min)) stop("min must be a single logical value (TRUE or FALSE).")
+  if (!is.null(QTAU)) {
+    if (!is.numeric(QTAU) || length(QTAU) != 1 || QTAU <= 0 || QTAU >= 1) {
+      stop("QTAU must be a single numeric value between 0 and 1 (exclusive).")
+    }
+  }
   
   # Prepare levels
   levels <- c(0.00, 0.25, 0.50, 0.75, 1)
@@ -52,21 +64,28 @@ compute_fars <- function(dep_variable,
   
   # Output structures
   Quantiles <- matrix(nrow = length(dep_variable), ncol = length(levels))
-  Scenario_Quantiles <- if (!is.null(scenario)) matrix(nrow = length(dep_variable), ncol = length(levels)) else NULL
+  Stressed_Quantiles <- if (!is.null(scenario)) matrix(nrow = length(dep_variable), ncol = length(levels)) else NULL
   coeff_df <- NULL
   pvalue_df <- NULL
   stderr_df <- NULL
+  Stressed_Factors <- NULL
+  
+  message("Running Factor-Augmented Quantile Regressions (FA-QRs)...")
+  
+  
+  if(!is.null(scenario)){
+    Stressed_Factors <- compute_stressed_factors(dep_variable,factors,scenario,h,QTAU,min)
+  }
   
-  message("Running Factor-Augmented Quantile Regressions (FARS)...")
   
   # Loop through each quantile and compute Qreg
   for (i in seq_along(levels)) {
     q <- levels[i]
 
-    QReg_result <- q_reg(dep_variable, factors = factors, scenario = scenario, h=h, QTAU = q, min = min)
+    QReg_result <- q_reg(dep_variable, factors, Stressed_Factors, h, q)
 
     if (!is.null(scenario)) {
-      Scenario_Quantiles[, i] <- QReg_result$Scenario_Pred_q
+      Stressed_Quantiles[, i] <- QReg_result$Stressed_Pred_q
     }
 
     Quantiles[, i] <- QReg_result$Pred_q
@@ -85,7 +104,7 @@ compute_fars <- function(dep_variable,
   
   
   result <- list(
-    Quantiles = Quantiles,
+    Quantiles = matrix(Quantiles,ncol = ncol(factors)),
     Coeff = coeff_df,
     StdError = stderr_df,
     Pvalue = pvalue_df,
@@ -93,7 +112,10 @@ compute_fars <- function(dep_variable,
   )
   
   if (!is.null(scenario)) {
-    result$Scenario_Quantiles <- Scenario_Quantiles
+    result$QTAU <- QTAU
+    result$Stressed_Factors <- matrix(Stressed_Factors, ncol = ncol(factors))
+    result$Stressed_Quantiles <- matrix(Stressed_Quantiles, ncol = ncol(factors))
+    
   }
   
   class(result) <- "fars"
