@@ -7,15 +7,13 @@
 orthogonalize_factors <- function(X) {
   n_factors <- ncol(X)  
   
-  
+  X <- Re(X)
   
   # Iterative orthogonalization
   for (i in 1:n_factors) {
     # Regress the i-th factor on all other factors (excluding itself)
     other_factors <- X[, -i, drop = FALSE]  
     model <- lm(X[, i] ~ other_factors)
-    
-    # Update the i-th factor with the residuals 
     X[, i] <- residuals(model)
   }
   
