@@ -13,7 +13,7 @@ summary.mldfm <- function(object, ...) {
   cat("Summary of Multilevel Dynamic Factor Model (MLDFM)\n")
   cat("===================================================\n")
   
-  cat("Number of observations: ", nrow(object$Factors), "\n")
+  cat("Time periods: ", nrow(object$Factors), "\n")
   cat("Total number of factors: ", ncol(object$Factors), "\n")
   cat("Number of nodes: ", length(object$Factors_list), "\n")
   
@@ -34,7 +34,7 @@ summary.mldfm <- function(object, ...) {
     rss <- sum(object$Residuals^2)
     avg_rss <- mean(rowSums(object$Residuals^2))
     cat("\nResidual sum of squares (RSS): ", formatC(rss, format = "f", digits = 4), "\n")
-    cat("Average RSS per observation: ", formatC(avg_rss, format = "f", digits = 4), "\n")
+    cat("Average RSS per time period: ", formatC(avg_rss, format = "f", digits = 4), "\n")
   }
   
   invisible(object)
